@@ -1,4 +1,5 @@
 from typing import Any
+from time import sleep
 
 from .base import BaseHTTP
 
@@ -18,6 +19,11 @@ class BlockingHTTP(BaseHTTP):
             resp = request(*args, **kwargs)
             if resp.status_code == 401:
                 self.authorize()
+            elif resp.status_code == 503 or resp.status_code == 429:
+                if "Retry-After" in resp.headers:
+                    sleep(float(resp.headers["Retry-After"]))
+                else:
+                    sleep(1.0)
             else:
                 return self.handle_resp(
                     resp,
