@@ -3,5 +3,6 @@ from ..shared_vars import KEY, KEY_ID
 
 CLIENT = Blocking(
     key_id=KEY_ID,
-    key=KEY
+    key=KEY,
+    timeout=320
 )
